@@ -571,6 +571,8 @@ KItinerary::Person ExtractorPostprocessorPrivate::processPerson(KItinerary::Pers
 
 PostalAddress ExtractorPostprocessorPrivate::processAddress(PostalAddress addr, const QString &phoneNumber, const GeoCoordinates &geo)
 {
+    addr.setAddressCountry(addr.addressCountry().simplified());
+
     // convert to ISO 3166-1 alpha-2 country codes
     if (addr.addressCountry().size() > 2) {
         QString alpha2Code;
@@ -614,8 +616,11 @@ PostalAddress ExtractorPostprocessorPrivate::processAddress(PostalAddress addr,
     }
 #endif
 
-    if (geo.isValid() && addr.addressCountry().isEmpty()) {
-        addr.setAddressCountry(KCountry::fromLocation(geo.latitude(), geo.longitude()).alpha2());
+    if (geo.isValid() && addr.addressCountry().size() != 2) {
+        const auto country = KCountry::fromLocation(geo.latitude(), geo.longitude());
+        if (country.isValid()) {
+            addr.setAddressCountry(country.alpha2());
+        }
     }
 
     AddressParser addrParser;
