@@ -9,19 +9,22 @@ function extractPdf(pdf) {
     const bookingId = text.match(/ID # ([^\d]*)(\d+)/);
     res.reservationNumber = bookingId[1] + bookingId[2];
     res.reservedTicket.ticketToken = 'qrCode:' + bookingId[2];
-    res.reservationFor.departureBusStop.name = text.match(/From: (.*?)  /)[1];
-    res.reservationFor.arrivalBusStop.name = text.match(/To: (.*?)  /)[1];
-    const dt = text.match(/(\d+ \S{3} \d{4}) (\d\d:\d\d).*(\d\d:\d\d)/);
+    res.reservationFor.departureBusStop.name = text.match(/From: *(\S.*?\S)  /)[1];
+    res.reservationFor.arrivalBusStop.name = text.match(/To: *(\S.*?\S)  /)[1];
+    const dt = text.match(/(\d+ \S{3} \d{4}) (\d\d:\d\d).*\n?.*Arrival .*(\d\d:\d\d)/);
     res.reservationFor.departureTime = JsonLd.toDateTime(dt[1] + dt[2], 'dd MMM yyyyhh:mm', 'en');
     res.reservationFor.arrivalTime = JsonLd.toDateTime(dt[1] + dt[3], 'dd MMM yyyyhh:mm', 'en');
-    const loc = text.match(/(\d+\.\d+) (\d+\.\d+)\n(.*)\n/);
+    const loc = text.match(/(\d+\.\d+) ,?(\d+\.\d+)\n(.*)\n/);
     res.reservationFor.departureBusStop.geo.latitude = loc[1];
     res.reservationFor.departureBusStop.geo.longitude = loc[2];
     const addr = loc[3].split(',');
     res.reservationFor.departureBusStop.address.addressCountry = addr[addr.length - 1];
     res.reservationFor.departureBusStop.address.addressLocality = addr[addr.length - 2];
     res.reservationFor.departureBusStop.address.streetAddress = addr.slice(0, addr.length -2).join(',');
-    res.priceCurrency = text.match(/Passenger.*\s+([A-Z]{3})/)[1];
-    res.totalPrice = text.match(/Total\s+([\d,]+)\n/)[1].replace(',', '');
+    const currency = text.match(/Passenger.*\s+([A-Z]{3})/);
+    if (currency) {
+        res.priceCurrency = currency[1];
+        res.totalPrice = text.match(/Total\s+([\d,]+)\n/)[1].replace(',', '');
+    }
     return res;
 }
