@@ -65,7 +65,9 @@ QDateTime SortUtil::startDateTime(const QVariant &elem)
             return flight.boardingTime();
         }
         QDateTime dt(flight.departureDay(), QTime(23, 59, 59));
-        dt.setTimeZone(KnowledgeDb::timezoneForAirport(KnowledgeDb::IataCode{flight.departureAirport().iataCode()}));
+        if (const auto tz = KnowledgeDb::timezoneForAirport(KnowledgeDb::IataCode{flight.departureAirport().iataCode()}); tz.isValid()) {
+            dt.setTimeZone(tz);
+        }
         return dt;
     }
     if (JsonLd::isA<TrainTrip>(elem)) {
@@ -179,6 +181,9 @@ bool SortUtil::isBefore(const QVariant &lhs, const QVariant &rhs)
 
 bool SortUtil::hasStartTime(const QVariant &elem)
 {
+    if (JsonLd::isA<FoodEstablishmentReservation>(elem)) {
+        return elem.value<FoodEstablishmentReservation>().startTime().isValid();
+    }
     if (JsonLd::canConvert<Reservation>(elem)) {
         return hasStartTime(JsonLd::convert<Reservation>(elem).reservationFor());
     }
@@ -194,6 +199,9 @@ bool SortUtil::hasStartTime(const QVariant &elem)
 
 bool SortUtil::hasEndTime(const QVariant &elem)
 {
+    if (JsonLd::isA<FoodEstablishmentReservation>(elem)) {
+        return elem.value<FoodEstablishmentReservation>().endTime().isValid();
+    }
     if (JsonLd::canConvert<Reservation>(elem)) {
         return hasEndTime(JsonLd::convert<Reservation>(elem).reservationFor());
     }
